@@ -30,6 +30,7 @@ import java.lang.reflect.Field;
 import java.util.Date;
 import java.util.Vector;
 import java.util.logging.Level;
+import org.apache.poi.hssf.usermodel.HSSFCellStyle;
 import org.apache.poi.hssf.usermodel.HSSFWorkbook;
 import org.apache.poi.ss.usermodel.Cell;
 import org.apache.poi.ss.usermodel.CellValue;
@@ -41,6 +42,8 @@ import org.apache.poi.ss.usermodel.Name;
 import org.apache.poi.ss.usermodel.Row;
 import org.apache.poi.ss.usermodel.Sheet;
 import org.apache.poi.ss.usermodel.WorkbookFactory;
+import org.apache.poi.ss.util.CellRangeAddress;
+import org.apache.poi.ss.util.CellReference;
 import org.apache.poi.ss.util.WorkbookUtil;
 import org.apache.poi.xssf.usermodel.XSSFCellStyle;
 import org.apache.poi.xssf.usermodel.XSSFWorkbook;
@@ -52,7 +55,10 @@ public class App
     {
         Logging.withLevel(Level.INFO);
 
-        // org.apache.poi.ss.usermodel.Workbook wb = WorkbookFactory.create(new FileInputStream("C:/Users/mstuder/Documents/GP-CTRLPARA-RBC 09 Q2 B1-V8.xls"));
+//        org.apache.poi.ss.usermodel.Workbook wb = WorkbookFactory.create(new FileInputStream("C:/Users/mstuder/Documents/repro.xlsx"));
+//        FormulaEvaluator evaluator = wb.getCreationHelper().createFormulaEvaluator();
+//        evaluator.evaluate(wb.getSheetAt(0).getRow(0).getCell(0));
+        
         // Name name = wb.getName("AM.input");
 
         // Workbook workbookx = Workbook.getWorkbook("C:/Users/mstuder/Documents/GP-CTRLPARA-RBC 09 Q2 B1-V8.xls", false);
@@ -97,41 +103,39 @@ public class App
 //        if(1 == 1) return;
 
 
-//        File f = new File("C:/Users/mstuder/Documents/Projects/Internal/XLConnect_Workspace/R/XLConnect/Whatever.xlsx");
+//        File f = new File("C:/Users/mstuder/Documents/errorCell.xls");
+//        Workbook wb = Workbook.getWorkbook(f, false);
+//        DataFrame dfx = wb.readNamedRegion("MyData", true);
+//        printDataFrame(dfx);
+
+
+//        File f = new File("C:/temp/test.xlsx");
 //        Workbook wb = Workbook.getWorkbook(f, true);
-//        wb.createSheet("test");
-//        wb.hideSheet("test", false);
+//        wb.createSheet("MySheet");
+//        wb.createSheet("Tada");
+//        wb.save();
+//        f.delete();
+//        wb.save();
+        
+        // CellStyle csx = wb.getCellStyle("Schlecht");
+        // wb.setCellStyle(0, 0, 0, csx);
+        // wb.save();
 
-        File f = new File("C:/Users/mstuder/Documents/bugrepro.xlsx");
-        Workbook wb = Workbook.getWorkbook(f, false);
-        DataFrame dfx = wb.readNamedRegion("dfRegion", true);
-        printDataFrame(dfx);
 
-        /*
-        org.apache.poi.ss.usermodel.Workbook wbOut = new XSSFWorkbook();
-        Sheet sheetOut = wbOut.createSheet("mysheet");
+        File f = new File("C:/temp/test.xlsx");
 
-        Row rowOut = sheetOut.createRow(0);
-        Cell cellOut = rowOut.createCell(0);
-        cellOut.setCellType(Cell.CELL_TYPE_NUMERIC);
-        cellOut.setCellValue(3.14159);
-        cellOut = rowOut.createCell(1);
-        cellOut.setCellType(Cell.CELL_TYPE_NUMERIC);
-        cellOut.setCellValue(new Date());
+        org.apache.poi.ss.usermodel.Workbook wb = new XSSFWorkbook();
+        Sheet s = wb.createSheet("MySheet");
+        
+        FileOutputStream fos1 = new FileOutputStream("C:/temp/test.xlsx", false);
+        wb.write(fos1);
+        fos1.close();
 
-        FileOutputStream fileOut = new FileOutputStream("C:/Users/mstuder/Documents/zzzz.xlsx");
-        wbOut.write(fileOut);
-        fileOut.close();
+        f.delete();
 
-        org.apache.poi.ss.usermodel.Workbook wbIn = WorkbookFactory.create(new FileInputStream("C:/Users/mstuder/Documents/zzzz.xlsx"));
-        Sheet sheetIn = wbIn.getSheetAt(0);
-        Row rowIn = sheetIn.getRow(0);
-        Cell cellIn = rowIn.getCell(0);
-        System.out.println(DateUtil.isCellDateFormatted(cellIn));
-        cellIn = rowIn.getCell(1);
-        System.out.println(DateUtil.isCellDateFormatted(cellIn));
-         *
-         */
+        FileOutputStream fos2 = new FileOutputStream("C:/temp/test.xlsx", false);
+        wb.write(fos2);
+        fos2.close();
 
         /*
         org.apache.poi.ss.usermodel.Workbook wbIn = WorkbookFactory.create(new FileInputStream("C:/Users/mstuder/Documents/bugrepro.xlsx"));
